@@ -29,6 +29,7 @@ import threading
 import time
 import weakref
 
+import ssh
 from ssh import util
 from ssh.auth_handler import AuthHandler
 from ssh.channel import Channel
@@ -194,7 +195,7 @@ class Transport (threading.Thread):
     """
 
     _PROTO_ID = '2.0'
-    _CLIENT_ID = 'ssh_1.7.8'
+    _CLIENT_ID = 'ssh_%s' % (ssh.__version__)
 
     _preferred_ciphers = ( 'aes128-ctr', 'aes256-ctr', 'aes128-cbc', 'blowfish-cbc', 'aes256-cbc', '3des-cbc',
         'arcfour128', 'arcfour256' )
